@@ -1,4 +1,4 @@
-#!/bin/sh -xe
+#!/bin/bash -xe
 
 PACKAGE_NAME=libqtpas
 TMP_DIR=`/bin/mktemp -d -t ${PACKAGE_NAME}.XXXXXX` || exit 1
@@ -12,21 +12,21 @@ do
 			VERSION=$1
 			;;
 		*)
-			ORIG_SRC_TAR=$(readlink -m $1)
 			;;
 	esac
 	shift
 done
 
-ORIG_SRC_DIR=lazarus/lcl/interfaces/qt5/cbindings
-DEB_SRC_DIR=${PACKAGE_NAME}-${VERSION}+dfsg
-DEB_SRC_TAR=${PACKAGE_NAME}_${VERSION}+dfsg.orig.tar.xz
+SHORT_VERSION=${VERSION::-5}
+ORIG_SRC_DIR=${PACKAGE_NAME}-${SHORT_VERSION}/lcl/interfaces/qt5/cbindings
+DEB_SRC_DIR=${PACKAGE_NAME}-${VERSION}
+DEB_SRC_TAR=${PACKAGE_NAME}_${VERSION}.orig.tar.xz
+ORIG_SRC_TAR=$(readlink -m ../${DEB_SRC_TAR})
 
 cd ${TMP_DIR}
 tar -axf ${ORIG_SRC_TAR} ${ORIG_SRC_DIR}
 mv ${ORIG_SRC_DIR} ${DEB_SRC_DIR}
 cd ${DEB_SRC_DIR}
-find -name Makefile.fpc -execdir sh -c 'rm $(basename {} .fpc)' ';'
 find '(' -name '*.icns' -or -name '*.java' ')' -exec chmod a-x {} ';'
 find -empty -delete
 cd ..
